@@ -1,19 +1,21 @@
 package Exporter::Lite;
 
-require 5.006;
-use warnings;
-use strict;
+require 5.004;
+
+# Using strict or vars almost doubles our load time.  Turn them back
+# on when debugging.
+#use strict 'vars';  # we're going to be doing a lot of sym refs
+#use vars qw($VERSION @EXPORT);
+
+$VERSION = 0.01;
+@EXPORT = qw(import);   # we'll know pretty fast if it doesn't work :)
 
-our $VERSION = '0.02_01';
-our @EXPORT = qw(import);
 
 
 sub import {
     my($exporter, @imports)  = @_;
     my($caller, $file, $line) = caller;
 
-    no strict 'refs';
-
     unless( @imports ) {        # Default import.
         @imports = @{$exporter.'::EXPORT'};
     }
@@ -47,8 +49,6 @@ sub import {
 sub _export {
     my($caller, $exporter, @imports) = @_;
 
-    no strict 'refs';
-
     # Stole this from Exporter::Heavy.  I'm sure it can be written better
     # but I'm lazy at the moment.
     foreach my $sym (@imports) {
@@ -80,7 +80,6 @@ sub _not_exported {
 1;
 
 __END__
-
 =head1 NAME
 
 Exporter::Lite - Lightweight exporting of variables
@@ -132,7 +131,7 @@ You have to ask for them.  C<use My::Module qw($Foo bar)>.
 =head1 Methods
 
 Export::Lite has one public method, import(), which is called
-automatically when your modules is use()'d.  
+automaticly when your modules is use()'d.  
 
 In normal usage you don't have to worry about this at all.
 
@@ -178,23 +177,12 @@ Exporter.  I know its at least on par.
 OTOH, the docs are much clearer and not having to say C<@ISA =
 qw(Exporter)> is kinda nice.
 
-=head1 REPOSITORY
-
-L<https://github.com/neilbowers/Exporter-Lite>
-
 =head1 AUTHORS
 
 Michael G Schwern <schwern@pobox.com>
 
-=head1 LICENSE
-
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
-
-See F<http://www.perl.com/perl/misc/Artistic.html>
-
 =head1 SEE ALSO
 
-L<Exporter>, L<Exporter::Simple>, L<UNIVERSAL::exports>
+L<Exporter>, L<UNIVERSAL::exports>
 
 =cut
